@@ -452,10 +452,11 @@ class FuncOnt:
 
     def AddPredFunction(self,ID,f):
         print 'Not implemented yet'
+        self.identList[ID].PrimaryCode=f
         return
-    def ClearPredFuncList(self):
-        print 'Not implemented yet'
-        return
+    #def ClearPredFuncList(self):
+    #    print 'Not implemented yet'
+    #    return
 
     def AddTriplesFromResults(self, SubjectConcept,PredicateConcept,ObjectConcept,results):
         """
@@ -1156,7 +1157,8 @@ class FuncOnt:
                             return 0
                     elif not forceFuncNoCall:
                         #couldn't find a match, so try to make a function call
-                        print 'Function Calls Not Implemented Yet'
+                        # print 'Function Calls Not Implemented Yet'
+                        bP.PrimaryCode(Sub, Pred, Obj, results, self)
                         return 0
                     return 0 #nothing to return
                 else:
@@ -1184,7 +1186,7 @@ class FuncOnt:
                     Pprime = None
                     for nt in theInvSet:
                         Pprime = self.GetEquivalentSuperClassInverseNodeList(nt.Pred)
-                        if len(Pprime)>0:
+                        if len(Pprime) > 0:
                             for pp in Pprime:
                                 predList.append(pp)
 
@@ -1237,7 +1239,7 @@ class FuncOnt:
         #print sys.path
         #_newcode = __import__(modulename, globals(), locals(), [], 0)
         _newcode = importlib.import_module(modulename)
-        print dir(_newcode)
+        # print dir(_newcode)
         rdfList = getattr(_newcode, 'OntologyFileList')
         internalOntology = getattr(_newcode,'InternalOntology')
         print 'Reading ontology: '+pkgname
@@ -1259,7 +1261,7 @@ class FuncOnt:
         #print sys.path
         #_newcode = __import__(modulename, globals(), locals(), [], 0)
         _newcode = __import__(modulename[:-3])
-        print dir(_newcode)
+        # print dir(_newcode)
         rdfList = getattr(_newcode, 'OntologyFileList')
         internalOntology = getattr(_newcode,'InternalOntology')
         print 'Reading ontology: '+mdlName
@@ -1292,7 +1294,8 @@ class FuncOnt:
                 self.AddTriple(s,p,o)
                 if 'fo:PrimaryCode' in p:
                     s_node=self.GetBON(s)
-                    s_node.PrimaryCode=getattr(_newcode,o)
+                    self.AddPredFunction(s,getattr(_newcode,o))
+                    #s_node.PrimaryCode=getattr(_newcode,o)
         return _newcode
 
 
